@@ -323,10 +323,8 @@ class TabSqliteDb:
         '''
         if DEBUG_LEVEL > 1:
             LOGGER.debug(
-                'input_phrase=%s phrase=%s user_freq=%s ',
-                input_phrase.encode('UTF-8'),
-                phrase.encode('UTF-8'),
-                user_freq)
+                'input_phrase=%r phrase=%r user_freq=%s ',
+                input_phrase, phrase, user_freq)
         if not input_phrase or not phrase:
             return
         input_phrase = itb_util.remove_accents(input_phrase.lower())
@@ -1055,6 +1053,30 @@ CREATE TABLE phrases (id INTEGER PRIMARY KEY, input_phrase TEXT, phrase TEXT, p_
                         commit=commit)
         return
 
+    def phrase_exists(self, phrase: str) -> int:
+        '''
+        Checks if an entry for phrase already exists in the user database
+
+        :param phrase: The phrase to check whether it is already recorded
+        :return: 0 if not in the database. > 0 if in the database.
+                 The value > 0 gives the sum(user_freq) in the database
+                 for phrase.
+        '''
+        if DEBUG_LEVEL > 1:
+            LOGGER.debug('phrase=%r', phrase)
+        if not phrase:
+            return 0
+        phrase = unicodedata.normalize(
+            itb_util.NORMALIZATION_FORM_INTERNAL, phrase)
+        select_sqlstr = '''
+        SELECT sum(user_freq) FROM user_db.phrases WHERE phrase = :phrase ;
+        '''
+        select_sqlargs = {'phrase': phrase}
+        retval = self.database.execute(select_sqlstr, select_sqlargs).fetchall()
+        if retval[0][0] is None:
+            return 0
+        return int(retval[0][0])
+
     def remove_phrase(
             self,
             input_phrase: str = '',
@@ -1066,9 +1088,7 @@ CREATE TABLE phrases (id INTEGER PRIMARY KEY, input_phrase TEXT, phrase TEXT, p_
         no matter for what input phrase from the database.
         '''
         if DEBUG_LEVEL > 1:
-            LOGGER.debug(
-                'TabSqliteDb.remove_phrase() phrase=%(p)s',
-                {'p': phrase.encode('UTF-8')})
+            LOGGER.debug('phrase=%r', phrase)
         if not phrase:
             return
         phrase = unicodedata.normalize(
