@@ -94,11 +94,29 @@ class M17nTranslitTestCase(unittest.TestCase):
         trans = m17n_translit.Transliterator('mr-itrans')
         self.assertEqual(trans.transliterate(list('praviN')), 'प्रविण्')
         self.assertEqual(trans.transliterate(list('namaste')), 'नमस्ते')
+        self.assertEqual(trans.transliterate(['n']), 'न्')
+        self.assertEqual(trans.transliterate(['n', ' ']), 'न् ')
+        self.assertEqual(trans.transliterate(['n', 'S-C-Return']), 'न्S-C-Return')
+        self.assertEqual(trans.transliterate(['S-C-Return']), 'S-C-Return')
 
     def test_hi_itrans(self) -> None:
         trans = m17n_translit.Transliterator('hi-itrans')
         self.assertEqual(trans.transliterate(list('namaste')), 'नमस्ते')
         self.assertEqual(trans.transliterate(list('. ')), '। ')
+        self.assertEqual(trans.transliterate(['S-C-Return']), 'S-C-Return')
+        self.assertEqual(trans.transliterate(['n']), 'न्')
+        self.assertEqual(trans.transliterate(['n', ' ']), 'न ')
+        self.assertEqual(trans.transliterate(['n', 'S-C-Return']), 'न्')
+        self.assertEqual(trans.transliterate(['n', 'S-C-Return', ' ']), 'न् ')
+        self.assertEqual(trans.transliterate(['n', 'T']), 'ण्ट्')
+        self.assertEqual(trans.transliterate(['n', 'T', 'S-C-Return']), 'ण्ट्')
+        self.assertEqual(trans.transliterate(['n', 'S-C-Return', 'T']), 'न्ट्')
+        self.assertEqual(trans.transliterate(['n', 'S-C-Return', 'T', ' ']), 'न्ट ')
+        self.assertEqual(trans.transliterate(['n', 'S-C-Return', 'T', 'S-C-Return']), 'न्ट्')
+        self.assertEqual(trans.transliterate(['n', 'S-C-Return', 'T', 'S-C-Return', ' ']), 'न्ट् ')
+        self.assertEqual(trans.transliterate(['a']), 'अ')
+        self.assertEqual(trans.transliterate(['a', ' ']), 'अ ')
+        self.assertEqual(trans.transliterate(['a', 'S-C-Return']), 'अS-C-Return')
 
     def test_unicode(self) -> None:
         trans = self.get_transliterator_or_skip('t-unicode')
