@@ -34,7 +34,9 @@ import unittest
 
 LOGGER = logging.getLogger('ibus-typing-booster')
 
+# pylint: disable=wrong-import-position
 import testutils # pylint: disable=import-error
+# pylint: enable=wrong-import-position
 
 IMPORT_DISTRO_SUCCESSFUL = False
 try:
@@ -43,6 +45,7 @@ try:
 except (ImportError,):
     IMPORT_DISTRO_SUCCESSFUL = False
 
+# pylint: disable=wrong-import-order
 # pylint: disable=wrong-import-position
 sys.path.insert(0, "../engine")
 # pylint: disable=import-error
@@ -51,6 +54,7 @@ import tabsqlitedb
 # pylint: disable=import-error
 sys.path.pop(0)
 # pylint: enable=wrong-import-position
+# pylint: enable=wrong-import-order
 
 # pylint: disable=missing-class-docstring
 # pylint: disable=missing-function-docstring
@@ -176,6 +180,49 @@ class TabSqliteDbTestCase(unittest.TestCase):
             self.database.select_words(
                 'baltim', p_phrase='foo', pp_phrase='bar')[0][0])
 
+    @unittest.skipUnless(
+        itb_util.get_hunspell_dictionary_wordlist('en_US')[0],
+        'Skipping because no en_US hunspell dictionary could be found.')
+    @unittest.skipUnless(
+        testutils.enchant_sanity_test(language='cs_CZ', word='Praha'),
+        'Skipping because python3-enchant seems broken for cs_CZ.')
+    @unittest.skipUnless(
+        testutils.enchant_working_as_expected(),
+        'Skipping because of an unexpected change in the enchant behaviour.')
+    @unittest.skipUnless(
+        testutils.get_hunspell_dictionary_length('en_US') >= 10000,
+        'Skipping because en_US dictionary is suspiciously small, '
+        'see: https://bugzilla.redhat.com/show_bug.cgi?id=2218460')
+    def test_add_phrase_to_database_and_check_existance(self) -> None:
+        self.init_database(
+            user_db_file=':memory:', dictionary_names=['en_US'])
+        self.assertEqual(
+            0,
+            self.database.phrase_exists('suoicodilaipxecitsiligarfilacrepus'))
+        self.database.add_phrase(
+            input_phrase='suoicodilaipxecitsiligarfilacrepus',
+            phrase='suoicodilaipxecitsiligarfilacrepus',
+            user_freq=1)
+        self.assertEqual(
+            [('suoicodilaipxecitsiligarfilacrepus', 1.0)],
+            self.database.select_words('suoicodilaipxecitsiligarfilacrepus'))
+        self.assertEqual(
+            1,
+            self.database.phrase_exists('suoicodilaipxecitsiligarfilacrepus'))
+        self.database.remove_phrase(
+            input_phrase='suoicodilaipxecitsiligarfilacrepus',
+            phrase='suoicodilaipxecitsiligarfilacrepus')
+        self.assertEqual(
+            0,
+            self.database.phrase_exists('suoicodilaipxecitsiligarfilacrepus'))
+        self.database.add_phrase(
+            input_phrase='suoicodilaipxecitsiligarfilacrepus',
+            phrase='suoicodilaipxecitsiligarfilacrepus',
+            user_freq=4711)
+        self.assertEqual(
+            4711,
+            self.database.phrase_exists('suoicodilaipxecitsiligarfilacrepus'))
+
     @unittest.skipUnless(
         itb_util.get_hunspell_dictionary_wordlist('en_US')[0],
         'Skipping because no en_US hunspell dictionary could be found.')
